Learn R Programming

RandVar (version 1.2.5)

RandVar-package: Implementation of Random Variables

Description

Implementation of random variables by means of S4 classes and methods.

Arguments

Author

Peter Ruckdeschel [email protected],
Matthias Kohl [email protected]
Maintainer: Matthias Kohl [email protected]

Package versions

Note: The first two numbers of package versions do not necessarily reflect package-individual development, but rather are chosen for the RobAStXXX family as a whole in order to ease updating "depends" information.

Details

Package:RandVar
Version:1.2.5
Date:2025-01-12
Depends:R(>= 3.4), methods, distr(>= 2.8.0), distrEx(>= 2.8.0)
Imports:startupmsg(>= 1.0.0)
ByteCompile:yes
License:LGPL-3
URL:https://r-forge.r-project.org/projects/robast/
VCS/SVNRevision:1319

References

M. Kohl (2005). Numerical Contributions to the Asymptotic Theory of Robustness. Dissertation. University of Bayreuth. See also https://www.stamats.de/wp-content/uploads/2018/04/ThesisMKohl.pdf

See Also

distr-package, distrEx-package

Examples

Run this code
library(RandVar)
#vignette("RandVar")

Run the code above in your browser using DataLab